#!/usr/bin/env python3

import requests
import os
import json
from argparse import ArgumentParser
from pathlib import Path
from typing import Optional
from dotenv import load_dotenv
from tqdm import tqdm


def create_labels(
    project_id: Optional[str], group_id: Optional[str], label_path: Path
) -> None:
    gitlab = os.environ["GITLAB_API_URL"]
    post_url = (
        f"{gitlab}/projects/{project_id}/labels"
        if project_id is not None
        else f"{gitlab}/groups/{group_id}/labels"
    )

    with open(label_path, "r") as f:
        labels = json.load(f)

    for label in tqdm(labels, desc="Creating labels", unit=" labels"):
        r = requests.post(
            post_url,
            label,
            headers={"Authorization": f"Bearer {os.environ['GITLAB_ACCESS_TOKEN']}"},
        )


def main() -> None:
    load_dotenv()

    parser = ArgumentParser(
        description="Automatically create a set of GitLab labels for a project or group."
    )

    target_group = parser.add_mutually_exclusive_group(required=True)
    target_group.add_argument(
        "--project",
        help="The id or URL encoded path of the project to create the labels for",
        type=str,
    )
    target_group.add_argument(
        "--group",
        help="The id or URL encoded path of the group to create the labels for",
        type=str,
    )

    parser.add_argument(
        "--labels",
        help="Path to a JSON file containg the labels to create",
        type=Path,
        default=Path(__file__).parent / "default_labels.json",
    )

    args = parser.parse_args()
    create_labels(args.project, args.group, args.labels)


if __name__ == "__main__":
    main()
